@@ -10,23 +10,26 @@
 #define DM_DIR "device-mapper"	/* Slashes not supported */
 #define DM_MAX_TYPE_NAME 16
 #define DM_NAME_LEN 128
+#define DM_UUID_LEN 129
 
 #ifdef __KERNEL__
 
 struct dm_table;
 struct dm_dev;
-typedef unsigned int offset_t;
+typedef unsigned long offset_t;
 
+typedef enum { STATUSTYPE_INFO, STATUSTYPE_TABLE } status_type_t;
 
 /*
  * Prototypes for functions for a target
  */
-typedef int (*dm_ctr_fn)(struct dm_table *t, offset_t b, offset_t l,
-			 int argc, char **argv, void **context);
-typedef void (*dm_dtr_fn)(struct dm_table *t, void *c);
-typedef int (*dm_map_fn)(struct buffer_head *bh, int rw, void *context);
-typedef int (*dm_err_fn)(struct buffer_head *bh, int rw, void *context);
-
+typedef int (*dm_ctr_fn) (struct dm_table *t, offset_t b, offset_t l,
+			  int argc, char **argv, void **context);
+typedef void (*dm_dtr_fn) (struct dm_table *t, void *c);
+typedef int (*dm_map_fn) (struct buffer_head *bh, int rw, void *context);
+typedef int (*dm_err_fn) (struct buffer_head *bh, int rw, void *context);
+typedef int (*dm_status_fn) (status_type_t status_type, char *result,
+			     int maxlen, void *context);
 
 void dm_error(const char *message);
 
@@ -48,6 +51,7 @@ struct target_type {
 	dm_dtr_fn dtr;
 	dm_map_fn map;
 	dm_err_fn err;
+	dm_status_fn status;
 };
 
 int dm_register_target(struct target_type *t);
