@@ -20,6 +20,10 @@ struct dm_task {
 	struct target *head, *tail;
 
 	int read_only;
+	int minor;
 	struct dm_ioctl *dmi;
+	char *newname;
+
+	char *uuid;
 };
 
